# -*- coding: utf-8 -*-
""" Viewing components for WAeUP objects.
"""
import grok
from waeup.browser import WAeUPPage, WAeUPEditFormPage
from waeup.interfaces import IUniversity, IWAeUPObject
from waeup.widgets.interfaces import ITableProvider

grok.templatedir('templates')

class LoginPage(WAeUPPage):
    """A login page, available for all objects.
    """
    grok.name('login')
    grok.context(IWAeUPObject)

    title = u'Login'
    camefrom = None

    def update(self, SUBMIT=None, camefrom=None):
        self.camefrom = camefrom
        if SUBMIT is not None:
            if self.request.principal.id != 'zope.anybody':
                self.flash('You logged in.')
                if not self.camefrom:
                    # User might have entered the URL directly. Let's beam
                    # him back to our context.
                    self.redirect(self.url(self.context))
                    return
                self.redirect(self.camefrom)
            self.flash('You entered wrong credentials!')


class LoginStaffPage(WAeUPPage):
    """A login page for staff members.
    """
    grok.context(IWAeUPObject)
    grok.name('loginstaff')
    grok.template('loginstaffpage')
    
    title = u'Staff Login'
    camefrom = None
    
    def update(self, SUBMIT=None):
        if SUBMIT is None:
            return
        self.flash('You logged in.')
        self.redirect(self.url(grok.getSite()))


class LoginStudentPage(WAeUPPage):
    """A login page for students.
    """
    grok.context(IWAeUPObject)
    grok.name('loginstudent')
    grok.template('loginstudentpage')
    title = u'Student Login'
    camefrom = None

    def update(self, SUBMIT=None):
        if SUBMIT is None:
            return
        self.flash('You logged in.')
        self.redirect(self.url(grok.getSite()))


class UniversityPage(WAeUPPage):
    """ The main university page.
    """
    grok.name('index')
    grok.context(IUniversity)
    title = u'Welcome to SRP'
    

class Manage(WAeUPEditFormPage):
    """Manage the basic properties of a `University` instance.
    """
    form_fields = grok.AutoFields(IUniversity)
    grok.context(IUniversity)
    grok.require('waeup.manageUniversity')
    title = u'Edit settings'

    @grok.action('Save')
    def save(self, **data):
        self.applyData(self.context, **data)
        self.flash('Settings have been saved.')
        return
    
    @grok.action('Save and return')
    def saveAndReturn(self, **data):
        self.applyData(self.context, **data)
        self.redirect(self.url(self.context))
        self.flash('Settings have been saved.')
        return

    @grok.action('Cancel')
    def cancel(self, **data):
        self.flash('Action cancelled.')
        self.redirect(self.url(self.context))
        return
